@@ -28,4 +28,4 @@ cache$set("df2", mtcars) # Set objects using `$set`.
 cache$get("df2") |>
   all.equal(mtcars)
 
-unlink(tf)
+unlink(tf, recursive = TRUE)
